import { getProgramDerivedAddress, getUtf8Encoder, getAddressEncoder, fixEncoderSize, getBytesEncoder, transformEncoder, getStructEncoder, getU8Encoder, getStructDecoder, fixDecoderSize, getBytesDecoder, getU8Decoder, getAddressDecoder, combineCodec, decodeAccount, assertAccountExists, fetchEncodedAccount, assertAccountsExist, fetchEncodedAccounts, getArrayEncoder, getArrayDecoder, getU64Encoder, getU64Decoder, getBooleanEncoder, getOptionEncoder, getBooleanDecoder, getOptionDecoder, getEnumEncoder, getEnumDecoder, getDiscriminatedUnionEncoder, getUnitEncoder, getTupleEncoder, getDiscriminatedUnionDecoder, getUnitDecoder, getTupleDecoder, containsBytes, AccountRole, upgradeRoleToSigner, isTransactionSigner as isTransactionSigner$1 } from '@solana/web3.js';

// src/helpers.ts
async function findAuthorityPda(config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({ programAddress, seeds: [] });
}
async function findMintProofPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("mint_proof"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findMintProofV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("mint_proof_v2"),
      getAddressEncoder().encode(seeds.mint),
      getAddressEncoder().encode(seeds.whitelist)
    ]
  });
}
async function findWhitelistPda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [fixEncoderSize(getBytesEncoder(), 32).encode(seeds.uuid)]
  });
}
async function findWhitelistV2Pda(seeds, config = {}) {
  const {
    programAddress = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW"
  } = config;
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("whitelist"),
      getAddressEncoder().encode(seeds.namespace),
      fixEncoderSize(getBytesEncoder(), 32).encode(seeds.uuid)
    ]
  });
}

// src/generated/accounts/authority.ts
function getAuthorityEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["bump", getU8Encoder()],
      ["cosigner", getAddressEncoder()],
      ["owner", getAddressEncoder()],
      ["reserved", fixEncoderSize(getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([36, 108, 254, 18, 167, 144, 27, 36])
    })
  );
}
function getAuthorityDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["bump", getU8Decoder()],
    ["cosigner", getAddressDecoder()],
    ["owner", getAddressDecoder()],
    ["reserved", fixDecoderSize(getBytesDecoder(), 64)]
  ]);
}
function getAuthorityCodec() {
  return combineCodec(getAuthorityEncoder(), getAuthorityDecoder());
}
function decodeAuthority(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getAuthorityDecoder()
  );
}
async function fetchAuthority(rpc, address, config) {
  const maybeAccount = await fetchMaybeAuthority(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthority(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeAuthority(maybeAccount);
}
async function fetchAllAuthority(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeAuthority(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeAuthority(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeAuthority(maybeAccount));
}
function getAuthoritySize() {
  return 137;
}
async function fetchAuthorityFromSeeds(rpc, config = {}) {
  const maybeAccount = await fetchMaybeAuthorityFromSeeds(rpc, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeAuthorityFromSeeds(rpc, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findAuthorityPda({ programAddress });
  return await fetchMaybeAuthority(rpc, address, fetchConfig);
}
function getMintProofEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["proofLen", getU8Encoder()],
      [
        "proof",
        getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32), { size: 28 })
      ]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([227, 131, 106, 240, 190, 48, 219, 228])
    })
  );
}
function getMintProofDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["proofLen", getU8Decoder()],
    [
      "proof",
      getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32), { size: 28 })
    ]
  ]);
}
function getMintProofCodec() {
  return combineCodec(getMintProofEncoder(), getMintProofDecoder());
}
function decodeMintProof(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMintProofDecoder()
  );
}
async function fetchMintProof(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProof(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProof(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMintProof(maybeAccount);
}
async function fetchAllMintProof(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProof(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProof(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProof(maybeAccount));
}
function getMintProofSize() {
  return 28;
}
async function fetchMintProofFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofPda(seeds, { programAddress });
  return await fetchMaybeMintProof(rpc, address, fetchConfig);
}
function getMintProofV2Encoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["proofLen", getU8Encoder()],
      [
        "proof",
        getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32), { size: 28 })
      ],
      ["creationSlot", getU64Encoder()],
      ["payer", getAddressEncoder()]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([22, 197, 150, 178, 249, 225, 183, 75])
    })
  );
}
function getMintProofV2Decoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["proofLen", getU8Decoder()],
    [
      "proof",
      getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32), { size: 28 })
    ],
    ["creationSlot", getU64Decoder()],
    ["payer", getAddressDecoder()]
  ]);
}
function getMintProofV2Codec() {
  return combineCodec(getMintProofV2Encoder(), getMintProofV2Decoder());
}
function decodeMintProofV2(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getMintProofV2Decoder()
  );
}
async function fetchMintProofV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeMintProofV2(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeMintProofV2(maybeAccount);
}
async function fetchAllMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeMintProofV2(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeMintProofV2(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeMintProofV2(maybeAccount));
}
function getMintProofV2Size() {
  return 945;
}
async function fetchMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeMintProofV2FromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeMintProofV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findMintProofV2Pda(seeds, { programAddress });
  return await fetchMaybeMintProofV2(rpc, address, fetchConfig);
}
function getWhitelistEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["version", getU8Encoder()],
      ["bump", getU8Encoder()],
      ["verified", getBooleanEncoder()],
      ["rootHash", fixEncoderSize(getBytesEncoder(), 32)],
      ["uuid", fixEncoderSize(getBytesEncoder(), 32)],
      ["name", fixEncoderSize(getBytesEncoder(), 32)],
      ["frozen", getBooleanEncoder()],
      ["voc", getOptionEncoder(getAddressEncoder())],
      ["fvc", getOptionEncoder(getAddressEncoder())],
      ["reserved", fixEncoderSize(getBytesEncoder(), 64)]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([204, 176, 52, 79, 146, 121, 54, 247])
    })
  );
}
function getWhitelistDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["version", getU8Decoder()],
    ["bump", getU8Decoder()],
    ["verified", getBooleanDecoder()],
    ["rootHash", fixDecoderSize(getBytesDecoder(), 32)],
    ["uuid", fixDecoderSize(getBytesDecoder(), 32)],
    ["name", fixDecoderSize(getBytesDecoder(), 32)],
    ["frozen", getBooleanDecoder()],
    ["voc", getOptionDecoder(getAddressDecoder())],
    ["fvc", getOptionDecoder(getAddressDecoder())],
    ["reserved", fixDecoderSize(getBytesDecoder(), 64)]
  ]);
}
function getWhitelistCodec() {
  return combineCodec(getWhitelistEncoder(), getWhitelistDecoder());
}
function decodeWhitelist(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getWhitelistDecoder()
  );
}
async function fetchWhitelist(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelist(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelist(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeWhitelist(maybeAccount);
}
async function fetchAllWhitelist(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelist(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelist(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelist(maybeAccount));
}
function getWhitelistSize() {
  return 238;
}
async function fetchWhitelistFromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistFromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistFromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistPda(seeds, { programAddress });
  return await fetchMaybeWhitelist(rpc, address, fetchConfig);
}
function getConditionEncoder() {
  return getStructEncoder([
    ["mode", getModeEncoder()],
    ["value", getAddressEncoder()]
  ]);
}
function getConditionDecoder() {
  return getStructDecoder([
    ["mode", getModeDecoder()],
    ["value", getAddressDecoder()]
  ]);
}
function getConditionCodec() {
  return combineCodec(getConditionEncoder(), getConditionDecoder());
}
function getFullMerkleProofEncoder() {
  return getStructEncoder([
    ["proof", getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32))],
    ["leaf", fixEncoderSize(getBytesEncoder(), 32)]
  ]);
}
function getFullMerkleProofDecoder() {
  return getStructDecoder([
    ["proof", getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32))],
    ["leaf", fixDecoderSize(getBytesDecoder(), 32)]
  ]);
}
function getFullMerkleProofCodec() {
  return combineCodec(getFullMerkleProofEncoder(), getFullMerkleProofDecoder());
}
var Mode = /* @__PURE__ */ ((Mode2) => {
  Mode2[Mode2["MerkleTree"] = 0] = "MerkleTree";
  Mode2[Mode2["VOC"] = 1] = "VOC";
  Mode2[Mode2["FVC"] = 2] = "FVC";
  return Mode2;
})(Mode || {});
function getModeEncoder() {
  return getEnumEncoder(Mode);
}
function getModeDecoder() {
  return getEnumDecoder(Mode);
}
function getModeCodec() {
  return combineCodec(getModeEncoder(), getModeDecoder());
}
function getOperationEncoder() {
  return getDiscriminatedUnionEncoder([
    ["Noop", getUnitEncoder()],
    ["Clear", getUnitEncoder()],
    [
      "Set",
      getStructEncoder([["fields", getTupleEncoder([getAddressEncoder()])]])
    ]
  ]);
}
function getOperationDecoder() {
  return getDiscriminatedUnionDecoder([
    ["Noop", getUnitDecoder()],
    ["Clear", getUnitDecoder()],
    [
      "Set",
      getStructDecoder([["fields", getTupleDecoder([getAddressDecoder()])]])
    ]
  ]);
}
function getOperationCodec() {
  return combineCodec(getOperationEncoder(), getOperationDecoder());
}
function operation(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOperation(kind, value) {
  return value.__kind === kind;
}
var State = /* @__PURE__ */ ((State2) => {
  State2[State2["Unfrozen"] = 0] = "Unfrozen";
  State2[State2["Frozen"] = 1] = "Frozen";
  return State2;
})(State || {});
function getStateEncoder() {
  return getEnumEncoder(State);
}
function getStateDecoder() {
  return getEnumDecoder(State);
}
function getStateCodec() {
  return combineCodec(getStateEncoder(), getStateDecoder());
}

// src/generated/accounts/whitelistV2.ts
function getWhitelistV2Encoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["version", getU8Encoder()],
      ["bump", getU8Encoder()],
      ["uuid", fixEncoderSize(getBytesEncoder(), 32)],
      ["state", getStateEncoder()],
      ["updateAuthority", getAddressEncoder()],
      ["namespace", getAddressEncoder()],
      ["freezeAuthority", getAddressEncoder()],
      ["conditions", getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([136, 184, 45, 191, 85, 203, 191, 119])
    })
  );
}
function getWhitelistV2Decoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["version", getU8Decoder()],
    ["bump", getU8Decoder()],
    ["uuid", fixDecoderSize(getBytesDecoder(), 32)],
    ["state", getStateDecoder()],
    ["updateAuthority", getAddressDecoder()],
    ["namespace", getAddressDecoder()],
    ["freezeAuthority", getAddressDecoder()],
    ["conditions", getArrayDecoder(getConditionDecoder())]
  ]);
}
function getWhitelistV2Codec() {
  return combineCodec(getWhitelistV2Encoder(), getWhitelistV2Decoder());
}
function decodeWhitelistV2(encodedAccount) {
  return decodeAccount(
    encodedAccount,
    getWhitelistV2Decoder()
  );
}
async function fetchWhitelistV2(rpc, address, config) {
  const maybeAccount = await fetchMaybeWhitelistV2(rpc, address, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2(rpc, address, config) {
  const maybeAccount = await fetchEncodedAccount(rpc, address, config);
  return decodeWhitelistV2(maybeAccount);
}
async function fetchAllWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await fetchAllMaybeWhitelistV2(rpc, addresses, config);
  assertAccountsExist(maybeAccounts);
  return maybeAccounts;
}
async function fetchAllMaybeWhitelistV2(rpc, addresses, config) {
  const maybeAccounts = await fetchEncodedAccounts(rpc, addresses, config);
  return maybeAccounts.map((maybeAccount) => decodeWhitelistV2(maybeAccount));
}
function getWhitelistV2Size() {
  return 239;
}
async function fetchWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const maybeAccount = await fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config);
  assertAccountExists(maybeAccount);
  return maybeAccount;
}
async function fetchMaybeWhitelistV2FromSeeds(rpc, seeds, config = {}) {
  const { programAddress, ...fetchConfig } = config;
  const [address] = await findWhitelistV2Pda(seeds, { programAddress });
  return await fetchMaybeWhitelistV2(rpc, address, fetchConfig);
}

// src/generated/errors/tensorWhitelist.ts
var TENSOR_WHITELIST_ERROR__BAD_COSIGNER = 6e3;
var TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION = 6001;
var TENSOR_WHITELIST_ERROR__MISSING_NAME = 6002;
var TENSOR_WHITELIST_ERROR__BAD_WHITELIST = 6003;
var TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG = 6004;
var TENSOR_WHITELIST_ERROR__BAD_OWNER = 6005;
var TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION = 6006;
var TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION = 6007;
var TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION = 6008;
var TENSOR_WHITELIST_ERROR__NO_CONDITIONS = 6009;
var TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY = 6010;
var TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT = 6011;
var TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX = 6012;
var TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS = 6013;
var TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS = 6014;
var TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS = 6015;
var TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN = 6016;
var TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF = 6017;
var TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF = 6018;
var tensorWhitelistErrorMessages;
if (process.env.NODE_ENV !== "production") {
  tensorWhitelistErrorMessages = {
    [TENSOR_WHITELIST_ERROR__BAD_COSIGNER]: `passed in cosigner doesnt have the rights to do this`,
    [TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF]: `bad mint proof`,
    [TENSOR_WHITELIST_ERROR__BAD_OWNER]: `passed in owner doesnt have the rights to do this`,
    [TENSOR_WHITELIST_ERROR__BAD_WHITELIST]: `bad whitelist`,
    [TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS]: `cannot have empty conditions`,
    [TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION]: `failed fvc verification`,
    [TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION]: `failed merkle proof verification`,
    [TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION]: `failed voc verification`,
    [TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY]: `invalid authority`,
    [TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX]: `invalid whitelist index`,
    [TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF]: `missing mint proof`,
    [TENSOR_WHITELIST_ERROR__MISSING_NAME]: `missing name`,
    [TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION]: `missing all 3 verification methods: at least one must be present`,
    [TENSOR_WHITELIST_ERROR__NO_CONDITIONS]: `no whitelist conditions provided`,
    [TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT]: `condition at index not a merkle root`,
    [TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG]: `proof provided exceeds the limit of 32 hashes`,
    [TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS]: `too many conditions`,
    [TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS]: `too many merkle proofs`,
    [TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN]: `whitelist is frozen`
  };
}
function getTensorWhitelistErrorMessage(code) {
  if (process.env.NODE_ENV !== "production") {
    return tensorWhitelistErrorMessages[code];
  }
  return "Error message not available in production bundles.";
}
var TENSOR_WHITELIST_PROGRAM_ADDRESS = "TL1ST2iRBzuGTqLn1KXnGdSnEow62BzPnGiqyRXhWtW";
var TensorWhitelistAccount = /* @__PURE__ */ ((TensorWhitelistAccount2) => {
  TensorWhitelistAccount2[TensorWhitelistAccount2["Authority"] = 0] = "Authority";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProofV2"] = 1] = "MintProofV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["MintProof"] = 2] = "MintProof";
  TensorWhitelistAccount2[TensorWhitelistAccount2["WhitelistV2"] = 3] = "WhitelistV2";
  TensorWhitelistAccount2[TensorWhitelistAccount2["Whitelist"] = 4] = "Whitelist";
  return TensorWhitelistAccount2;
})(TensorWhitelistAccount || {});
function identifyTensorWhitelistAccount(account) {
  const data = account instanceof Uint8Array ? account : account.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([36, 108, 254, 18, 167, 144, 27, 36])
    ),
    0
  )) {
    return 0 /* Authority */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([22, 197, 150, 178, 249, 225, 183, 75])
    ),
    0
  )) {
    return 1 /* MintProofV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([227, 131, 106, 240, 190, 48, 219, 228])
    ),
    0
  )) {
    return 2 /* MintProof */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([136, 184, 45, 191, 85, 203, 191, 119])
    ),
    0
  )) {
    return 3 /* WhitelistV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([204, 176, 52, 79, 146, 121, 54, 247])
    ),
    0
  )) {
    return 4 /* Whitelist */;
  }
  throw new Error(
    "The provided account could not be identified as a tensorWhitelist account."
  );
}
var TensorWhitelistInstruction = /* @__PURE__ */ ((TensorWhitelistInstruction2) => {
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelist"] = 0] = "FreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateAuthority"] = 1] = "InitUpdateAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateMintProof"] = 2] = "InitUpdateMintProof";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateWhitelist"] = 3] = "InitUpdateWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocAuthority"] = 4] = "ReallocAuthority";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["ReallocWhitelist"] = 5] = "ReallocWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelist"] = 6] = "UnfreezeWhitelist";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CreateWhitelistV2"] = 7] = "CreateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UpdateWhitelistV2"] = 8] = "UpdateWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["InitUpdateMintProofV2"] = 9] = "InitUpdateMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["CloseMintProofV2"] = 10] = "CloseMintProofV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["FreezeWhitelistV2"] = 11] = "FreezeWhitelistV2";
  TensorWhitelistInstruction2[TensorWhitelistInstruction2["UnfreezeWhitelistV2"] = 12] = "UnfreezeWhitelistV2";
  return TensorWhitelistInstruction2;
})(TensorWhitelistInstruction || {});
function identifyTensorWhitelistInstruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([248, 112, 12, 150, 175, 238, 38, 184])
    ),
    0
  )) {
    return 0 /* FreezeWhitelist */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([53, 144, 79, 150, 196, 110, 22, 55])
    ),
    0
  )) {
    return 1 /* InitUpdateAuthority */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([30, 77, 123, 9, 191, 37, 52, 159])
    ),
    0
  )) {
    return 2 /* InitUpdateMintProof */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([255, 1, 192, 134, 111, 49, 212, 131])
    ),
    0
  )) {
    return 3 /* InitUpdateWhitelist */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([128, 120, 16, 197, 85, 34, 2, 91])
    ),
    0
  )) {
    return 4 /* ReallocAuthority */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([173, 147, 168, 152, 181, 46, 55, 60])
    ),
    0
  )) {
    return 5 /* ReallocWhitelist */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([215, 119, 9, 92, 160, 139, 226, 253])
    ),
    0
  )) {
    return 6 /* UnfreezeWhitelist */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([31, 207, 213, 77, 105, 13, 127, 98])
    ),
    0
  )) {
    return 7 /* CreateWhitelistV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([184, 188, 157, 214, 205, 49, 74, 226])
    ),
    0
  )) {
    return 8 /* UpdateWhitelistV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([35, 185, 181, 108, 143, 139, 228, 45])
    ),
    0
  )) {
    return 9 /* InitUpdateMintProofV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([237, 78, 8, 208, 47, 148, 145, 170])
    ),
    0
  )) {
    return 10 /* CloseMintProofV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([69, 158, 243, 78, 116, 68, 221, 113])
    ),
    0
  )) {
    return 11 /* FreezeWhitelistV2 */;
  }
  if (containsBytes(
    data,
    fixEncoderSize(getBytesEncoder(), 8).encode(
      new Uint8Array([51, 105, 214, 84, 252, 188, 26, 1])
    ),
    0
  )) {
    return 12 /* UnfreezeWhitelistV2 */;
  }
  throw new Error(
    "The provided instruction could not be identified as a tensorWhitelist instruction."
  );
}
function expectSome(value) {
  if (value == null) {
    throw new Error("Expected a value but received null or undefined.");
  }
  return value;
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}

// src/generated/instructions/closeMintProofV2.ts
function getCloseMintProofV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([237, 78, 8, 208, 47, 148, 145, 170])
    })
  );
}
function getCloseMintProofV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getCloseMintProofV2InstructionDataCodec() {
  return combineCodec(
    getCloseMintProofV2InstructionDataEncoder(),
    getCloseMintProofV2InstructionDataDecoder()
  );
}
function getCloseMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    signer: { value: input.signer ?? null, isWritable: true },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.signer),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCloseMintProofV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCloseMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      signer: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCloseMintProofV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getCreateWhitelistV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["uuid", fixEncoderSize(getBytesEncoder(), 32)],
      ["freezeAuthority", getOptionEncoder(getAddressEncoder())],
      ["conditions", getArrayEncoder(getConditionEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([31, 207, 213, 77, 105, 13, 127, 98])
    })
  );
}
function getCreateWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["uuid", fixDecoderSize(getBytesDecoder(), 32)],
    ["freezeAuthority", getOptionDecoder(getAddressDecoder())],
    ["conditions", getArrayDecoder(getConditionDecoder())]
  ]);
}
function getCreateWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getCreateWhitelistV2InstructionDataEncoder(),
    getCreateWhitelistV2InstructionDataDecoder()
  );
}
async function getCreateWhitelistV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistV2Pda({
      namespace: expectAddress(accounts.namespace.value),
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getCreateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    namespace: { value: input.namespace ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.namespace),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getCreateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCreateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      namespace: getNextAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getCreateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([248, 112, 12, 150, 175, 238, 38, 184])
    })
  );
}
function getFreezeWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getFreezeWhitelistInstructionDataCodec() {
  return combineCodec(
    getFreezeWhitelistInstructionDataEncoder(),
    getFreezeWhitelistInstructionDataDecoder()
  );
}
async function getFreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getFreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getFreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getFreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getFreezeWhitelistV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([69, 158, 243, 78, 116, 68, 221, 113])
    })
  );
}
function getFreezeWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getFreezeWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getFreezeWhitelistV2InstructionDataEncoder(),
    getFreezeWhitelistV2InstructionDataDecoder()
  );
}
function getFreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getFreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseFreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getFreezeWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}
function getInitUpdateAuthorityInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["newCosigner", getOptionEncoder(getAddressEncoder())],
      ["newOwner", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([53, 144, 79, 150, 196, 110, 22, 55])
    })
  );
}
function getInitUpdateAuthorityInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["newCosigner", getOptionDecoder(getAddressDecoder())],
    ["newOwner", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getInitUpdateAuthorityInstructionDataCodec() {
  return combineCodec(
    getInitUpdateAuthorityInstructionDataEncoder(),
    getInitUpdateAuthorityInstructionDataDecoder()
  );
}
async function getInitUpdateAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    owner: { value: input.owner ?? null, isWritable: false },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateAuthorityInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateAuthorityInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateMintProofInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["proof", getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([30, 77, 123, 9, 191, 37, 52, 159])
    })
  );
}
function getInitUpdateMintProofInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["proof", getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32))]
  ]);
}
function getInitUpdateMintProofInstructionDataCodec() {
  return combineCodec(
    getInitUpdateMintProofInstructionDataEncoder(),
    getInitUpdateMintProofInstructionDataDecoder()
  );
}
async function getInitUpdateMintProofInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofPda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateMintProofInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mint: { value: input.mint ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    user: { value: input.user ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.user),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateMintProofInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      mint: getNextAccount(),
      mintProof: getNextAccount(),
      user: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateMintProofInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateMintProofV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["proof", getArrayEncoder(fixEncoderSize(getBytesEncoder(), 32))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([35, 185, 181, 108, 143, 139, 228, 45])
    })
  );
}
function getInitUpdateMintProofV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["proof", getArrayDecoder(fixDecoderSize(getBytesDecoder(), 32))]
  ]);
}
function getInitUpdateMintProofV2InstructionDataCodec() {
  return combineCodec(
    getInitUpdateMintProofV2InstructionDataEncoder(),
    getInitUpdateMintProofV2InstructionDataDecoder()
  );
}
async function getInitUpdateMintProofV2InstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.mintProof.value) {
    accounts.mintProof.value = await findMintProofV2Pda({
      mint: expectAddress(accounts.mint.value),
      whitelist: expectAddress(accounts.whitelist.value)
    });
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateMintProofV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    mint: { value: input.mint ?? null, isWritable: false },
    whitelist: { value: input.whitelist ?? null, isWritable: false },
    mintProof: { value: input.mintProof ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.mint),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.mintProof),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateMintProofV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateMintProofV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      mint: getNextAccount(),
      whitelist: getNextAccount(),
      mintProof: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateMintProofV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getInitUpdateWhitelistInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["uuid", fixEncoderSize(getBytesEncoder(), 32)],
      ["rootHash", getOptionEncoder(fixEncoderSize(getBytesEncoder(), 32))],
      ["name", getOptionEncoder(fixEncoderSize(getBytesEncoder(), 32))],
      ["voc", getOptionEncoder(getAddressEncoder())],
      ["fvc", getOptionEncoder(getAddressEncoder())]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([255, 1, 192, 134, 111, 49, 212, 131])
    })
  );
}
function getInitUpdateWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["uuid", fixDecoderSize(getBytesDecoder(), 32)],
    ["rootHash", getOptionDecoder(fixDecoderSize(getBytesDecoder(), 32))],
    ["name", getOptionDecoder(fixDecoderSize(getBytesDecoder(), 32))],
    ["voc", getOptionDecoder(getAddressDecoder())],
    ["fvc", getOptionDecoder(getAddressDecoder())]
  ]);
}
function getInitUpdateWhitelistInstructionDataCodec() {
  return combineCodec(
    getInitUpdateWhitelistInstructionDataEncoder(),
    getInitUpdateWhitelistInstructionDataDecoder()
  );
}
async function getInitUpdateWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.whitelist.value) {
    accounts.whitelist.value = await findWhitelistPda({
      uuid: expectSome(args.uuid)
    });
  }
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function getInitUpdateWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getInitUpdateWhitelistInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitUpdateWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getInitUpdateWhitelistInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getReallocAuthorityInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([128, 120, 16, 197, 85, 34, 2, 91])
    })
  );
}
function getReallocAuthorityInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getReallocAuthorityInstructionDataCodec() {
  return combineCodec(
    getReallocAuthorityInstructionDataEncoder(),
    getReallocAuthorityInstructionDataDecoder()
  );
}
async function getReallocAuthorityInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocAuthorityInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: true
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 3) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocAuthorityInstructionDataDecoder().decode(instruction.data)
  };
}
function getReallocWhitelistInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([173, 147, 168, 152, 181, 46, 55, 60])
    })
  );
}
function getReallocWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getReallocWhitelistInstructionDataCodec() {
  return combineCodec(
    getReallocWhitelistInstructionDataEncoder(),
    getReallocWhitelistInstructionDataDecoder()
  );
}
async function getReallocWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getReallocWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    cosigner: { value: input.cosigner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.cosigner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getReallocWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseReallocWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      cosigner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getReallocWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([215, 119, 9, 92, 160, 139, 226, 253])
    })
  );
}
function getUnfreezeWhitelistInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getUnfreezeWhitelistInstructionDataCodec() {
  return combineCodec(
    getUnfreezeWhitelistInstructionDataEncoder(),
    getUnfreezeWhitelistInstructionDataDecoder()
  );
}
async function getUnfreezeWhitelistInstructionAsync(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.whitelistAuthority.value) {
    accounts.whitelistAuthority.value = await findAuthorityPda();
  }
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function getUnfreezeWhitelistInstruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    whitelistAuthority: {
      value: input.whitelistAuthority ?? null,
      isWritable: false
    },
    owner: { value: input.owner ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.whitelistAuthority),
      getAccountMeta(accounts.owner),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUnfreezeWhitelistInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      whitelist: getNextAccount(),
      whitelistAuthority: getNextAccount(),
      owner: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUnfreezeWhitelistInstructionDataDecoder().decode(instruction.data)
  };
}
function getUnfreezeWhitelistV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", fixEncoderSize(getBytesEncoder(), 8)]]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([51, 105, 214, 84, 252, 188, 26, 1])
    })
  );
}
function getUnfreezeWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)]
  ]);
}
function getUnfreezeWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getUnfreezeWhitelistV2InstructionDataEncoder(),
    getUnfreezeWhitelistV2InstructionDataDecoder()
  );
}
function getUnfreezeWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    freezeAuthority: {
      value: input.freezeAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.freezeAuthority),
      getAccountMeta(accounts.whitelist)
    ],
    programAddress,
    data: getUnfreezeWhitelistV2InstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseUnfreezeWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 2) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      freezeAuthority: getNextAccount(),
      whitelist: getNextAccount()
    },
    data: getUnfreezeWhitelistV2InstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getUpdateWhitelistV2InstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", fixEncoderSize(getBytesEncoder(), 8)],
      ["freezeAuthority", getOperationEncoder()],
      ["conditions", getOptionEncoder(getArrayEncoder(getConditionEncoder()))]
    ]),
    (value) => ({
      ...value,
      discriminator: new Uint8Array([184, 188, 157, 214, 205, 49, 74, 226])
    })
  );
}
function getUpdateWhitelistV2InstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", fixDecoderSize(getBytesDecoder(), 8)],
    ["freezeAuthority", getOperationDecoder()],
    ["conditions", getOptionDecoder(getArrayDecoder(getConditionDecoder()))]
  ]);
}
function getUpdateWhitelistV2InstructionDataCodec() {
  return combineCodec(
    getUpdateWhitelistV2InstructionDataEncoder(),
    getUpdateWhitelistV2InstructionDataDecoder()
  );
}
function getUpdateWhitelistV2Instruction(input) {
  const programAddress = TENSOR_WHITELIST_PROGRAM_ADDRESS;
  const originalAccounts = {
    payer: { value: input.payer ?? null, isWritable: true },
    updateAuthority: { value: input.updateAuthority ?? null, isWritable: true },
    newUpdateAuthority: {
      value: input.newUpdateAuthority ?? null,
      isWritable: false
    },
    whitelist: { value: input.whitelist ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.updateAuthority),
      getAccountMeta(accounts.newUpdateAuthority),
      getAccountMeta(accounts.whitelist),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getUpdateWhitelistV2InstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseUpdateWhitelistV2Instruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  const getNextOptionalAccount = () => {
    const accountMeta = getNextAccount();
    return accountMeta.address === TENSOR_WHITELIST_PROGRAM_ADDRESS ? void 0 : accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      payer: getNextAccount(),
      updateAuthority: getNextAccount(),
      newUpdateAuthority: getNextOptionalAccount(),
      whitelist: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getUpdateWhitelistV2InstructionDataDecoder().decode(instruction.data)
  };
}

// src/helpers.ts
var intoAddress = (data) => {
  const decoder = getAddressDecoder();
  return decoder.decode(Uint8Array.from(data));
};
var fromAddress = (address) => {
  const encoder = getAddressEncoder();
  return encoder.encode(address);
};
var collIdToBuffer = (collId) => {
  return Buffer.from(collId.split("-").join(""));
};
var bufferToCollId = (buffer) => {
  const raw = String.fromCharCode(...buffer);
  return `${raw.slice(0, 8)}-${raw.slice(8, 12)}-${raw.slice(
    12,
    16
  )}-${raw.slice(16, 20)}-${raw.slice(20)}`;
};
async function getWhitelistFromCollId(collId) {
  const uuid = collIdToBuffer(collId);
  const whitelistSeeds = {
    uuid
  };
  const [whitelistPda] = await findWhitelistPda(whitelistSeeds);
  return whitelistPda;
}

export { Mode, State, TENSOR_WHITELIST_ERROR__BAD_COSIGNER, TENSOR_WHITELIST_ERROR__BAD_MINT_PROOF, TENSOR_WHITELIST_ERROR__BAD_OWNER, TENSOR_WHITELIST_ERROR__BAD_WHITELIST, TENSOR_WHITELIST_ERROR__EMPTY_CONDITIONS, TENSOR_WHITELIST_ERROR__FAILED_FVC_VERIFICATION, TENSOR_WHITELIST_ERROR__FAILED_MERKLE_PROOF_VERIFICATION, TENSOR_WHITELIST_ERROR__FAILED_VOC_VERIFICATION, TENSOR_WHITELIST_ERROR__INVALID_AUTHORITY, TENSOR_WHITELIST_ERROR__INVALID_WHITELIST_INDEX, TENSOR_WHITELIST_ERROR__MISSING_MINT_PROOF, TENSOR_WHITELIST_ERROR__MISSING_NAME, TENSOR_WHITELIST_ERROR__MISSING_VERIFICATION, TENSOR_WHITELIST_ERROR__NOT_MERKLE_ROOT, TENSOR_WHITELIST_ERROR__NO_CONDITIONS, TENSOR_WHITELIST_ERROR__PROOF_TOO_LONG, TENSOR_WHITELIST_ERROR__TOO_MANY_CONDITIONS, TENSOR_WHITELIST_ERROR__TOO_MANY_MERKLE_PROOFS, TENSOR_WHITELIST_ERROR__WHITELIST_IS_FROZEN, TENSOR_WHITELIST_PROGRAM_ADDRESS, TensorWhitelistAccount, TensorWhitelistInstruction, bufferToCollId, collIdToBuffer, decodeAuthority, decodeMintProof, decodeMintProofV2, decodeWhitelist, decodeWhitelistV2, fetchAllAuthority, fetchAllMaybeAuthority, fetchAllMaybeMintProof, fetchAllMaybeMintProofV2, fetchAllMaybeWhitelist, fetchAllMaybeWhitelistV2, fetchAllMintProof, fetchAllMintProofV2, fetchAllWhitelist, fetchAllWhitelistV2, fetchAuthority, fetchAuthorityFromSeeds, fetchMaybeAuthority, fetchMaybeAuthorityFromSeeds, fetchMaybeMintProof, fetchMaybeMintProofFromSeeds, fetchMaybeMintProofV2, fetchMaybeMintProofV2FromSeeds, fetchMaybeWhitelist, fetchMaybeWhitelistFromSeeds, fetchMaybeWhitelistV2, fetchMaybeWhitelistV2FromSeeds, fetchMintProof, fetchMintProofFromSeeds, fetchMintProofV2, fetchMintProofV2FromSeeds, fetchWhitelist, fetchWhitelistFromSeeds, fetchWhitelistV2, fetchWhitelistV2FromSeeds, findAuthorityPda, findMintProofPda, findMintProofV2Pda, findWhitelistPda, findWhitelistV2Pda, fromAddress, getAuthorityCodec, getAuthorityDecoder, getAuthorityEncoder, getAuthoritySize, getCloseMintProofV2Instruction, getCloseMintProofV2InstructionDataCodec, getCloseMintProofV2InstructionDataDecoder, getCloseMintProofV2InstructionDataEncoder, getConditionCodec, getConditionDecoder, getConditionEncoder, getCreateWhitelistV2Instruction, getCreateWhitelistV2InstructionAsync, getCreateWhitelistV2InstructionDataCodec, getCreateWhitelistV2InstructionDataDecoder, getCreateWhitelistV2InstructionDataEncoder, getFreezeWhitelistInstruction, getFreezeWhitelistInstructionAsync, getFreezeWhitelistInstructionDataCodec, getFreezeWhitelistInstructionDataDecoder, getFreezeWhitelistInstructionDataEncoder, getFreezeWhitelistV2Instruction, getFreezeWhitelistV2InstructionDataCodec, getFreezeWhitelistV2InstructionDataDecoder, getFreezeWhitelistV2InstructionDataEncoder, getFullMerkleProofCodec, getFullMerkleProofDecoder, getFullMerkleProofEncoder, getInitUpdateAuthorityInstruction, getInitUpdateAuthorityInstructionAsync, getInitUpdateAuthorityInstructionDataCodec, getInitUpdateAuthorityInstructionDataDecoder, getInitUpdateAuthorityInstructionDataEncoder, getInitUpdateMintProofInstruction, getInitUpdateMintProofInstructionAsync, getInitUpdateMintProofInstructionDataCodec, getInitUpdateMintProofInstructionDataDecoder, getInitUpdateMintProofInstructionDataEncoder, getInitUpdateMintProofV2Instruction, getInitUpdateMintProofV2InstructionAsync, getInitUpdateMintProofV2InstructionDataCodec, getInitUpdateMintProofV2InstructionDataDecoder, getInitUpdateMintProofV2InstructionDataEncoder, getInitUpdateWhitelistInstruction, getInitUpdateWhitelistInstructionAsync, getInitUpdateWhitelistInstructionDataCodec, getInitUpdateWhitelistInstructionDataDecoder, getInitUpdateWhitelistInstructionDataEncoder, getMintProofCodec, getMintProofDecoder, getMintProofEncoder, getMintProofSize, getMintProofV2Codec, getMintProofV2Decoder, getMintProofV2Encoder, getMintProofV2Size, getModeCodec, getModeDecoder, getModeEncoder, getOperationCodec, getOperationDecoder, getOperationEncoder, getReallocAuthorityInstruction, getReallocAuthorityInstructionAsync, getReallocAuthorityInstructionDataCodec, getReallocAuthorityInstructionDataDecoder, getReallocAuthorityInstructionDataEncoder, getReallocWhitelistInstruction, getReallocWhitelistInstructionAsync, getReallocWhitelistInstructionDataCodec, getReallocWhitelistInstructionDataDecoder, getReallocWhitelistInstructionDataEncoder, getStateCodec, getStateDecoder, getStateEncoder, getTensorWhitelistErrorMessage, getUnfreezeWhitelistInstruction, getUnfreezeWhitelistInstructionAsync, getUnfreezeWhitelistInstructionDataCodec, getUnfreezeWhitelistInstructionDataDecoder, getUnfreezeWhitelistInstructionDataEncoder, getUnfreezeWhitelistV2Instruction, getUnfreezeWhitelistV2InstructionDataCodec, getUnfreezeWhitelistV2InstructionDataDecoder, getUnfreezeWhitelistV2InstructionDataEncoder, getUpdateWhitelistV2Instruction, getUpdateWhitelistV2InstructionDataCodec, getUpdateWhitelistV2InstructionDataDecoder, getUpdateWhitelistV2InstructionDataEncoder, getWhitelistCodec, getWhitelistDecoder, getWhitelistEncoder, getWhitelistFromCollId, getWhitelistSize, getWhitelistV2Codec, getWhitelistV2Decoder, getWhitelistV2Encoder, getWhitelistV2Size, identifyTensorWhitelistAccount, identifyTensorWhitelistInstruction, intoAddress, isOperation, operation, parseCloseMintProofV2Instruction, parseCreateWhitelistV2Instruction, parseFreezeWhitelistInstruction, parseFreezeWhitelistV2Instruction, parseInitUpdateAuthorityInstruction, parseInitUpdateMintProofInstruction, parseInitUpdateMintProofV2Instruction, parseInitUpdateWhitelistInstruction, parseReallocAuthorityInstruction, parseReallocWhitelistInstruction, parseUnfreezeWhitelistInstruction, parseUnfreezeWhitelistV2Instruction, parseUpdateWhitelistV2Instruction };
//# sourceMappingURL=index.mjs.map
//# sourceMappingURL=index.mjs.map